# PersonSet

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**logic** | **str** |  | [optional] 
**expression** | [**BooleanExpression**](BooleanExpression.md) |  | [optional] 
**subsets** | [**list[PersonSet]**](PersonSet.md) |  | [optional] 
**enabled** | **bool** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

